@@ -1,31 +1,31 @@
 from shapely.geometry import shape
 import sqlite_utils
+from sqlite_utils.utils import find_spatialite
 
 import inspect
 import itertools
 import json
 import os
 
-SPATIALITE_PATHS = (
-    "/usr/lib/x86_64-linux-gnu/mod_spatialite.so",
-    "/usr/local/lib/mod_spatialite.dylib",
-)
-
 
 class SpatiaLiteError(Exception):
     pass
 
 
-def yield_records(features, pk, spatialite):
+def yield_records(features, pk, properties, spatialite):
     for feature in features:
         record = {}
         if "id" in feature:
             record["id"] = feature["id"]
-        record.update(feature.get("properties") or {})
-        if spatialite:
-            record["geometry"] = shape(feature["geometry"]).wkt
+        if properties:
+            record[properties] = feature.get("properties") or {}
         else:
-            record["geometry"] = feature["geometry"]
+            record.update(feature.get("properties") or {})
+        geometry = feature.get("geometry")
+        if spatialite and geometry:
+            geometry = shape(geometry).wkt
+
+        record["geometry"] = geometry
         yield record
 
 
@@ -35,6 +35,7 @@ def import_features(
     features,
     pk=None,
     alter=False,
+    properties="",
     spatialite=False,
     spatialite_mod=None,
     spatial_index=False,
@@ -45,7 +46,7 @@ def import_features(
     # grab a sample, for checking ids
     sample_geojson = list(itertools.islice(features, 100))
     features = itertools.chain(sample_geojson, features)
-    sample_records = list(yield_records(sample_geojson, pk, spatialite))
+    sample_records = list(yield_records(sample_geojson, pk, properties, spatialite))
 
     if pk is None and has_ids(sample_records):
         pk = "id"
@@ -60,20 +61,26 @@ def import_features(
         if not lib:
             raise SpatiaLiteError("Could not find SpatiaLite module")
 
-        init_spatialite(db, lib)
+        db.init_spatialite(lib)
 
         if table not in db.table_names():
             # Create the table, using detected column types
             column_types = sqlite_utils.suggest_column_types(sample_records)
             column_types.pop("geometry")
+            remove_tmp_column = False
+            if not column_types:
+                remove_tmp_column = False
+                column_types["_tmp"] = str
             db[table].create(column_types, pk=pk)
             ensure_table_has_geometry(db, table)
+            if remove_tmp_column:
+                db[table].transform(drop={"_tmp"})
 
         conversions = {"geometry": "GeomFromText(?, 4326)"}
 
     if pk:
         db[table].upsert_all(
-            yield_records(features, pk, spatialite),
+            yield_records(features, pk, properties, spatialite),
             conversions=conversions,
             pk=pk,
             alter=alter,
@@ -81,11 +88,12 @@ def import_features(
 
     else:
         db[table].insert_all(
-            yield_records(features, pk, spatialite), conversions=conversions
+            yield_records(features, pk, properties, spatialite), conversions=conversions
         )
 
     if spatial_index:
-        db.conn.execute("select CreateSpatialIndex(?, ?)", [table, "geometry"])
+        # db.conn.execute("select CreateSpatialIndex(?, ?)", [table, "geometry"])
+        db[table].create_spatial_index("geometry")
 
     return db[table]
 
@@ -114,27 +122,9 @@ def get_features(geojson_file, nl=False):
     return geojson.get("features", [])
 
 
-def find_spatialite():
-    for path in SPATIALITE_PATHS:
-        if os.path.exists(path):
-            return path
-    return None
-
-
-def init_spatialite(db, lib):
-    db.conn.enable_load_extension(True)
-    db.conn.load_extension(lib)
-    # Initialize SpatiaLite if not yet initialized
-    if "spatial_ref_sys" in db.table_names():
-        return
-    db.conn.execute("select InitSpatialMetadata(1)")
-
-
 def ensure_table_has_geometry(db, table):
     if "geometry" not in db[table].columns_dict:
-        db.conn.execute(
-            "SELECT AddGeometryColumn(?, 'geometry', 4326, 'GEOMETRY', 2);", [table]
-        )
+        db[table].add_geometry_column("geometry", "GEOMETRY")
 
 
 def has_ids(features):
